"use client"

import Modal from "@/components/Modal";
import useFaqs, { IFaqProps } from "@/hooks/useFaq";
import { faMagnifyingGlass, faTimes } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { ChangeEvent, HTMLProps, useRef, useState } from "react";

interface ISearchInputProps extends HTMLProps<HTMLInputElement> {
	helperText?: string;
	labelText?: string;
	topic?: string;
}

const SearchFaqInput = ({
	helperText,
	labelText,
	topic,
	...props
}: ISearchInputProps) => {

	const [resultBox, setResultBox] = useState(false)

	const faqs = useFaqs(topic ?? "all")

	const [results, setResults] = useState<typeof faqs>([])

	const userSearchInput = useRef<HTMLInputElement | null>(null)

	const [openModal, setOpenModal] = useState(false)

	const [modalData, setModalData] = useState<IFaqProps | null>(null)


	const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
		const search = e.currentTarget.value;


		if (search.length > 0) {
			setResultBox(!resultBox)
		}

		// console.log(search)
		if (search.length >= 2) {
			setResults(
				[...(faqs.filter((faq) =>
					faq.title.toLowerCase().includes(search.toLowerCase()) ||
					faq.text.toLowerCase().includes(search.toLowerCase())
				))]
			)
			// setSearchString(search);
		} else {
			// setSearchString("");
			setResults([])
		}
	};


	const showModal = (data: IFaqProps) => {
		setOpenModal(true)
		setModalData(data)
	}


	return (
		<>
			{
				openModal && modalData !== null ?
					<Modal title={modalData.title} isOpen={openModal} setIsOpen={setOpenModal} >
						{modalData.text}
					</Modal>
					: null
			}
			<div className="relative">
				{
					// JSON.stringify(faqs)
				}
				<div className="">
					<label
						htmlFor="faq-search"
						className="block text-center text-regular sr-only"
					>
						{labelText ?? "Search FAQs"}
					</label>
					<form className="flex items-center relative">
						<FontAwesomeIcon icon={faMagnifyingGlass} className="h-4 w-4 absolute ml-4" />
						<input
							id="faq-search"
							ref={userSearchInput}
							onChange={handleChange}
							className="px-10 py-2 w-full rounded-[4em] outline-none border-2 focus:border-rfw-summer focus:ring-rfw-dark placeholder"
							{...props}
						/>

						{
							userSearchInput.current?.value ?
								<button
									type="reset"
									onClick={() => {
										setResults([])
										if (userSearchInput.current) {
											userSearchInput.current.value = ""
										}
									}
									}
									className="h-4 w-4 absolute right-0 mr-4 flex items-center hover:text-rfw-summer"
								>
									<FontAwesomeIcon icon={faTimes} />
								</button>
								: null
						}

					</form>
				</div>

				{
					results.length > 0 && userSearchInput.current?.value ?
						<div
							className="absolute w-full z-20 mt-2 rounded-xl  bg-white px-8 py-4 rounded-b-lg border flex flex-col justify-center items-center overflow-y-scroll overflow-x-hidden" >
							{
								results.map((faq, idx) => (
									<p onClick={() => showModal(faq)} key={"results-faq-" + idx} className="block p-1.5 w-full hover:font-normal font-light cursor-pointer">
										{faq.title}
									</p>
								))

							}
						</div>
						: null
				}
				{
					results.length === 0 && userSearchInput.current?.value ?
						<div
							className="absolute z-20 mt-2 rounded-xl w-full bg-white px-8 py-4 rounded-b-lg border flex flex-col justify-center items-center overflow-y-scroll overflow-x-hidden" >
							<p className="text-sm font-light">No results found</p>
						</div>
						: null
				}

			</div >
		</>
	);
};

export default SearchFaqInput;
